@@ -30,7 +30,7 @@ regist_parsing_function('bool', parse_bool_element)
 
 function parse_multi_select_element(element){
     let value = $('.form-check-input:checked', element).map(function(){
-        let v = $(this).parent().text().trim()
+        let v = $(this).parent().attr('select-item-key')
         return v
     }).toArray()
     return value
